@@ -31,7 +31,7 @@ class FaucetMetrics(PromClient):
     _dpid_gauges = None  # type: dict
 
     def __init__(self, reg=None):
-        super(FaucetMetrics, self).__init__(reg=reg)
+        super().__init__(reg=reg)
         self.PORT_REQUIRED_LABELS = self.REQUIRED_LABELS + ['port', 'port_description']
         self._dpid_counters = {}
         self._dpid_gauges = {}
@@ -234,6 +234,7 @@ class FaucetMetrics(PromClient):
             gauge.labels(**dp_labels).set(0)
 
     def inc_var(self, var, labels, val=1):
+        """Increment a variable."""
         assert labels is not None
         metrics_var = getattr(self, var)
         metrics_var.labels(**labels).inc(val)
