@@ -410,6 +410,7 @@ class ValveRouteManager(ValveManagerBase):
         raise NotImplementedError # pragma: no cover
 
     def add_vlan(self, vlan, cold_start):
+        """Add a VLAN."""
         ofmsgs = []
         # add controller IPs if configured.
         for faucet_vip in vlan.faucet_vips_by_ipv(self.IPV):
@@ -422,6 +423,14 @@ class ValveRouteManager(ValveManagerBase):
                 vlan, priority, faucet_vip, faucet_vip_host))
         return ofmsgs
 
+    def del_vlan(self, vlan):
+        """Delete a VLAN."""
+        ofmsgs = []
+        if vlan.faucet_vips_by_ipv:
+            ofmsgs.append(self.fib_table.flowdel(
+                match=self.fib_table.match(vlan=vlan)))
+        return ofmsgs
+
     def _add_resolved_route(self, vlan, ip_gw, ip_dst, eth_dst, is_updated):
         """Return flowmods for enabling routing of a resolved nexthop"""
         ofmsgs = []
