@@ -24,7 +24,6 @@ from faucet import valve_of
 from faucet import valve_packet
 from faucet.valve_manager_base import ValveManagerBase
 from faucet.vlan import NullVLAN
-from faucet import valve_table
 
 
 class ValveSwitchManager(ValveManagerBase):  # pylint: disable=too-many-public-methods
@@ -375,43 +374,43 @@ class ValveSwitchManager(ValveManagerBase):  # pylint: disable=too-many-public-m
         return None
 
     def lacp_advertise(self, port):
+        """Return flows to send LACP if active."""
         ofmsgs = []
         if port.running() and port.lacp_active:
             ofmsgs.extend(self.lacp_req_reply(port.dyn_last_lacp_pkt, port))
         return ofmsgs
 
+    def _lacp_match(self, port):
+        return self.vlan_table.match(
+            in_port=port.number,
+            eth_type=valve_of.ether.ETH_TYPE_SLOW,
+            eth_dst=valve_packet.SLOW_PROTOCOL_MULTICAST)
+
     def add_port(self, port):
         ofmsgs = []
         if port.vlans():
             mirror_act = port.mirror_actions()
-            tagged_ofmsgs = []
             for vlan in port.tagged_vlans:
-                tagged_ofmsgs.append(self._port_add_vlan_rules(
+                ofmsgs.append(self._port_add_vlan_rules(
                     port, vlan, mirror_act, push_vlan=False))
-            untagged_ofmsgs = []
             native_vlan = self._native_vlan(port)
             if native_vlan is not None:
-                untagged_ofmsgs.append(self._port_add_vlan_rules(
+                ofmsgs.append(self._port_add_vlan_rules(
                     port, native_vlan, mirror_act))
             # If no untagged VLANs, add explicit drop rule for untagged packets.
-            if port.count_untag_vlan_miss and not untagged_ofmsgs:
-                untagged_ofmsgs.append(self.vlan_table.flowmod(
+            elif port.count_untag_vlan_miss:
+                ofmsgs.append(self.vlan_table.flowdrop(
                     self.vlan_table.match(in_port=port.number, vlan=NullVLAN()),
                     priority=self.low_priority))
-            ofmsgs.extend(tagged_ofmsgs)
-            ofmsgs.extend(untagged_ofmsgs)
             if port.lacp:
                 ofmsgs.append(self.vlan_table.flowcontroller(
-                    self.vlan_table.match(
-                        in_port=port.number,
-                        eth_type=valve_of.ether.ETH_TYPE_SLOW,
-                        eth_dst=valve_packet.SLOW_PROTOCOL_MULTICAST),
+                    self._lacp_match(port),
                     priority=self.dp_highest_priority,
                     max_len=valve_packet.LACP_SIZE))
                 ofmsgs.extend(self.lacp_advertise(port))
         return ofmsgs
 
-    def del_port(self, port):
+    def _del_host_flows(self, port):
         ofmsgs = []
         ofmsgs.append(
             self.eth_src_table.flowdel(self.eth_src_table.match(in_port=port.number)))
@@ -420,13 +419,25 @@ class ValveSwitchManager(ValveManagerBase):  # pylint: disable=too-many-public-m
                 # per OF 1.3.5 B.6.23, the OFA will match flows
                 # that have an action targeting this port.
                 ofmsgs.append(table.flowdel(out_port=port.number))
-        for vlan in port.vlans():
-            vlan.clear_cache_hosts_on_port(port)
-        native_vlan = self._native_vlan(port)
-        if native_vlan is not None:
-            ofmsgs.append(self.vlan_table.flowdel(
-                self.vlan_table.match(in_port=port.number, vlan=port.native_vlan),
-                priority=self.low_priority))
+        return ofmsgs
+
+    def del_port(self, port):
+        ofmsgs = []
+        if port.vlans():
+            ofmsgs.extend(self._del_host_flows(port))
+            native_vlan = self._native_vlan(port)
+            if native_vlan is not None or port.count_untag_vlan_miss:
+                ofmsgs.append(self.vlan_table.flowdel(
+                    self.vlan_table.match(in_port=port.number, vlan=NullVLAN()),
+                    priority=self.low_priority))
+            for vlan in port.tagged_vlans:
+                ofmsgs.append(self.vlan_table.flowdel(
+                    self.vlan_table.match(in_port=port.number, vlan=vlan),
+                    priority=self.low_priority))
+            if port.lacp:
+                ofmsgs.append(self.vlan_table.flowdel(
+                    self._lacp_match(port),
+                    priority=self.dp_highest_priority))
         return ofmsgs
 
     def _build_flood_rules(self, vlan, cold_start, modify=False):
@@ -643,19 +654,20 @@ class ValveSwitchManager(ValveManagerBase):  # pylint: disable=too-many-public-m
             same_lag = (port.lacp and port.lacp == cache_port.lacp)
             guard_time = self.cache_update_guard_time
             if cache_port == port or same_lag:
+                port_cache_valid = (
+                    port.dyn_update_time is not None and port.dyn_update_time <= entry.cache_time)
                 # aggressively re-learn on LAGs
                 if same_lag:
                     guard_time = 2
                 # port didn't change status, and recent cache update, don't do anything.
-                if (cache_age < guard_time and
-                        port.dyn_update_time is not None and
-                        port.dyn_update_time <= entry.cache_time):
+                if cache_age < guard_time and port_cache_valid:
                     update_cache = False
                     learn_exit = True
                 # skip delete if host didn't change ports or on same LAG.
                 elif cache_port == port or same_lag:
                     delete_existing = False
-                    refresh_rules = True
+                    if port_cache_valid:
+                        refresh_rules = True
         return (learn_exit, ofmsgs, cache_port, update_cache, delete_existing, refresh_rules)
 
     def _loop_protect_check(self, entry, vlan, now, eth_src, port, ofmsgs,  # pylint: disable=unused-argument
