@@ -30,6 +30,8 @@ from ryu.ofproto import ofproto_v1_3_parser as parser
 from faucet import valve_of
 from faucet import valve_packet
 
+import yaml
+
 from clib.valve_test_lib import (
     CONFIG, DP1_CONFIG, FAUCET_MAC, GROUP_DP1_CONFIG, IDLE_DP1_CONFIG,
     ValveTestBases)
@@ -182,6 +184,57 @@ dps:
         self.assertTrue(table.is_output(match, port=3))
 
 
+class ValveUnusedMeterTestCase(ValveTestBases.ValveTestNetwork):
+    """Test unused meters are not configured."""
+
+    CONFIG = """
+meters:
+    unusedmeter:
+        meter_id: 1
+        entry:
+            flags: "KBPS"
+            bands:
+                [
+                    {
+                        type: "DROP",
+                        rate: 1
+                    }
+                ]
+    usedmeter:
+        meter_id: 2
+        entry:
+            flags: "KBPS"
+            bands:
+                [
+                    {
+                        type: "DROP",
+                        rate: 2
+                    }
+                ]
+acls:
+    meteracl:
+        - rule:
+            actions:
+                meter: usedmeter
+                allow: 1
+dps:
+    s1:
+%s
+        interfaces:
+            p1:
+                number: 1
+                native_vlan: 0x100
+                acls_in: [meteracl]
+""" % DP1_CONFIG
+
+    def setUp(self):
+        self.setup_valves(self.CONFIG)
+
+    def test_usedmeter(self):
+        valve = self.valves_manager.valves[self.DP_ID]
+        self.assertEqual(['usedmeter'], list(valve.dp.meters.keys()))
+
+
 class ValveOFErrorTestCase(ValveTestBases.ValveTestNetwork):
     """Test decoding of OFErrors."""
 
@@ -735,6 +788,11 @@ routers:
     def setUp(self):
         self.setup_valves(self.CONFIG)
 
+    def test_unmirror(self):
+        config = yaml.load(self.CONFIG, Loader=yaml.SafeLoader)
+        del config['dps']['s1']['interfaces']['p5']['mirror']
+        self.update_config(yaml.dump(config), reload_type='warm')
+
 
 if __name__ == "__main__":
     unittest.main() # pytype: disable=module-attr
